==> qt-creator-opensource-src-4.2.0.zip: qt-creator-opensource-src-4.2.0/src/plugins/qnx/qnxrunconfiguration.h <==
/****************************************************************************
**
** Copyright (C) 2016 BlackBerry Limited. All rights reserved.
** Contact: KDAB (info@kdab.com)
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <remotelinux/remotelinuxrunconfiguration.h>

namespace Qnx {
namespace Internal {

class QnxRunConfiguration : public RemoteLinux::RemoteLinuxRunConfiguration
{
    Q_OBJECT

public:
    QnxRunConfiguration(ProjectExplorer::Target *parent, Core::Id id,
                        const QString &targetName);

    ProjectExplorer::Runnable runnable() const override;

    QWidget *createConfigurationWidget() override;
    QVariantMap toMap() const override;

private:
    friend class QnxRunConfigurationFactory;

    QnxRunConfiguration(ProjectExplorer::Target *parent, QnxRunConfiguration *source);
    bool fromMap(const QVariantMap &map) override;

    QString m_qtLibPath;
};

} // namespace Internal
} // namespace Qnx

==> qt-creator-opensource-src-4.7.2.zip: qt-creator-opensource-src-4.7.2/src/plugins/qnx/qnxrunconfiguration.h <==
/****************************************************************************
**
** Copyright (C) 2016 BlackBerry Limited. All rights reserved.
** Contact: KDAB (info@kdab.com)
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <projectexplorer/runconfigurationaspects.h>
#include <remotelinux/remotelinuxrunconfiguration.h>

namespace Qnx {
namespace Internal {

class QtLibPathAspect : public ProjectExplorer::BaseStringAspect
{
    Q_OBJECT

public:
    QtLibPathAspect(ProjectExplorer::RunConfiguration *rc) : BaseStringAspect(rc) {}
};

class QnxRunConfiguration : public RemoteLinux::RemoteLinuxRunConfiguration
{
    Q_OBJECT

public:
    QnxRunConfiguration(ProjectExplorer::Target *target, Core::Id id);

private:
    ProjectExplorer::Runnable runnable() const override;
    void fillConfigurationLayout(QFormLayout *layout) const override;
};

class QnxRunConfigurationFactory : public ProjectExplorer::RunConfigurationFactory
{
public:
    QnxRunConfigurationFactory();
};

} // namespace Internal
} // namespace Qnx
